import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/components/rank.dart';

import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';

class LeaderBoardTable extends StatefulWidget {
  const LeaderBoardTable({super.key});

  @override
  State<LeaderBoardTable> createState() => _LeaderBoardTableState();
}

class _LeaderBoardTableState extends State<LeaderBoardTable> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  GamificationStorageService storageService =
      Get.find<GamificationStorageService>();
  LeaderBoardModel currentUser = LeaderBoardModel();

  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  String userId = '';
  int _selectedIndex = 0;
  @override
  initState() {
    super.initState();

    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
    storageService.getString('userId').then((value) => {
          setState(() {
            userId = value.toString();
          })
        });
  }

  @override
  Widget build(BuildContext context) {
    return Flex(direction: Axis.vertical, children: [
      SizedBox(
          width: MediaQuery.of(context).size.width,
          height: 200,
          child: const Rank()),
      Expanded(
          child: LayoutBuilder(
        builder: (context, constraints) => ListView.separated(
          shrinkWrap: true,
          itemCount: leaderBoardController.leaderBoardData.isNotEmpty
              ? leaderBoardController.leaderBoardData.length
              : 0,
          itemBuilder: (BuildContext context, int index) {
            if (index >= 3) {
              return leaderBoardController.leaderBoardData.isNotEmpty
                  ? ListTile(
                      tileColor: Colors.white,
                      selectedTileColor: Colors.white,
                      contentPadding: const EdgeInsets.only(
                          left: 30, right: 8, top: 8.0, bottom: 8.0),
                      selected: leaderBoardController
                              .leaderBoardData[index].userId
                              .toString() ==
                          userId,
                      leading: Container(
                        decoration: const BoxDecoration(
                          shape: BoxShape.circle,
                          color: Color.fromARGB(255, 238, 234, 234),
                        ),
                        child: Padding(
                            padding: const EdgeInsets.all(7.75),
                            child: Text(
                              "4",
                              textAlign: TextAlign.start,
                              style: const TextStyle(
                                  fontWeight: FontWeight.w600,
                                  fontSize: 16,
                                  fontFamily: 'Poppins'),
                            )),
                      ),
                      title: Wrap(
                          spacing: 16.0,
                          crossAxisAlignment: WrapCrossAlignment.center,
                          children: [
                            Expanded(
                                flex: 8,
                                child: Container(
                                    width: 48.0,
                                    height: 48.0,
                                    decoration: const BoxDecoration(
                                      shape: BoxShape.circle,
                                    ),
                                    child: ClipOval(
                                        child: CachedNetworkImage(
                                      key: UniqueKey(),
                                      imageUrl:
                                          "https://expertphotography.b-cdn.net/wp-content/uploads/2020/08/profile-photos-4.jpg",
                                      width: 50.0,
                                      height: 50.0,
                                      fit: BoxFit.fill,
                                      placeholder: (context, url) => Container(
                                        child: Image.asset(
                                          "assets/icons/avatar.png",
                                          package: "progamification",
                                        ),
                                      ),
                                      errorWidget: (context, url, error) =>
                                          Container(
                                        child: Image.asset(
                                          "assets/icons/avatar.png",
                                          package: "progamification",
                                        ),
                                      ),
                                    )))),
                            Expanded(
                                flex: 8,
                                child: Text(
                                  "abi",
                                  textAlign: TextAlign.start,
                                  style: const TextStyle(
                                      fontWeight: FontWeight.w800,
                                      fontSize: 16,
                                      fontFamily: 'Poppins'),
                                )),
                          ]),
                      trailing: Wrap(
                        direction: Axis.horizontal,
                        crossAxisAlignment: WrapCrossAlignment.center,
                        spacing: 9.0,
                        children: [
                          Expanded(
                            flex: 2,
                            child: Text(
                              '${leaderBoardController.leaderBoardData[index].score} points',
                              textAlign: TextAlign.start,
                              style: const TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 15,
                                  fontFamily: 'Poppins'),
                            ),
                          ),
                        ],
                      ),
                    )
                  : const SizedBox(
                      height: 0,
                      width: 0,
                    );
            } else {
              return Container();
            }
          },
          separatorBuilder: (BuildContext context, int index) {
            if (index >= 3) {
              return Container(
                height: 1,
                color: Color.fromARGB(255, 238, 234, 234),
                padding: EdgeInsets.zero,
              );
            } else {
              return Container();
            }
          },
        ),
      ))
    ]);
  }
}
