import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';

class Rank extends StatefulWidget {
  const Rank({super.key});

  @override
  State<Rank> createState() => _RankState();
}

class _RankState extends State<Rank> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  GamificationStorageService storageService =
      Get.find<GamificationStorageService>();
  LeaderBoardModel currentUser = LeaderBoardModel();

  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  String userId = '';
  int _selectedIndex = 0;
  @override
  initState() {
    super.initState();

    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
    storageService.getString('userId').then((value) => {
          setState(() {
            userId = value.toString();
          })
        });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        decoration: const BoxDecoration(
          border: Border(
            bottom: BorderSide(
                width: 1.5, color: Color.fromARGB(255, 238, 234, 234)),
          ),
          color: Colors.white,
        ),
        padding: const EdgeInsets.only(
            top: 25.0, left: 5.0, right: 5.0, bottom: 30.0),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            Column(mainAxisAlignment: MainAxisAlignment.end, children: [
              Stack(
                clipBehavior: Clip.none,
                children: [
                  Container(
                    decoration: const BoxDecoration(
                      shape: BoxShape.circle,
                    ),
                    child: ClipOval(
                        child: CachedNetworkImage(
                      key: UniqueKey(),
                      imageUrl: leaderBoardController
                              .leaderBoardData[1].profileImageUrl
                              .toString() +
                          sasToken,
                      width: 50.0,
                      height: 50.0,
                      fit: BoxFit.fill,
                      placeholder: (context, url) => Container(
                        child: Image.asset(
                          "assets/icons/avatar.png",
                          package: "progamification",
                        ),
                      ),
                      errorWidget: (context, url, error) => Container(
                        child: Image.asset(
                          "assets/icons/avatar.png",
                          package: "progamification",
                        ),
                      ),
                    )),
                  ),
                  Positioned(
                    bottom: -11,
                    left: 17,
                    child: Container(
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: Colors.grey[300],
                          border: Border.all(
                            color: Colors.white,
                            width: 1.5,
                          ),
                        ),
                        child: Padding(
                            padding: EdgeInsets.all(4.0),
                            child: Text(
                              leaderBoardController.leaderBoardData[1].rank
                                  .toString(),
                              textAlign: TextAlign.start,
                              style: const TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 14,
                                  fontFamily: 'Poppins'),
                            ))),
                  ),
                ],
              ),
              Padding(
                  padding: EdgeInsets.only(top: 10.0),
                  child: Column(children: [
                    Text(
                      leaderBoardController.leaderBoardData[1].userName
                          .toString(),
                      style: const TextStyle(
                        fontWeight: FontWeight.w600,
                        fontSize: 16,
                        fontFamily: 'PlusJakartaSans-SemiBold',
                      ),
                    ),
                    Text(
                      '${leaderBoardController.leaderBoardData[1].score} points',
                      style: const TextStyle(
                        fontWeight: FontWeight.w400,
                        fontSize: 16,
                        fontFamily: 'PlusJakartaSans-Regular',
                      ),
                    )
                  ]))
            ]),
            Column(
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                Stack(clipBehavior: Clip.none, children: [
                  Container(
                      decoration: const BoxDecoration(
                        shape: BoxShape.circle,
                      ),
                      child: ClipOval(
                        child: CachedNetworkImage(
                            key: UniqueKey(),
                            imageUrl: leaderBoardController
                                    .leaderBoardData[0].profileImageUrl
                                    .toString() +
                                sasToken,
                            width: 65,
                            height: 65,
                            fit: BoxFit.fill,
                            placeholder: (context, url) => Container(
                                  child: Image.asset(
                                    "assets/icons/avatar.png",
                                    package: "progamification",
                                  ),
                                ),
                            errorWidget: (context, url, error) => Container(
                                  child: Image.asset(
                                    "assets/icons/avatar.png",
                                    package: "progamification",
                                  ),
                                )),
                      )),
                  Positioned(
                    bottom: -11,
                    left: 23,
                    child: Container(
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: Colors.grey[300],
                          border: Border.all(
                            color: Colors.white,
                            width: 1.5,
                          ),
                        ),
                        child: Padding(
                            padding: const EdgeInsets.all(4.0),
                            child: Text(
                              leaderBoardController.leaderBoardData[0].rank
                                  .toString(),
                              textAlign: TextAlign.start,
                              style: const TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 14,
                                  fontFamily: 'Poppins'),
                            ))),
                  ),
                ]),
                Padding(
                    padding: EdgeInsets.only(top: 10.0),
                    child: Column(children: [
                      Text(
                        leaderBoardController.leaderBoardData[0].userName
                            .toString(),
                        style: const TextStyle(
                          fontWeight: FontWeight.w600,
                          fontSize: 16,
                          fontFamily: 'PlusJakartaSans-SemiBold',
                        ),
                      ),
                      Text(
                        '${leaderBoardController.leaderBoardData[0].score} points',
                        style: const TextStyle(
                          fontWeight: FontWeight.w400,
                          fontSize: 16,
                          fontFamily: 'PlusJakartaSans-Regular',
                        ),
                      )
                    ]))
              ],
            ),
            Column(mainAxisAlignment: MainAxisAlignment.end, children: [
              Stack(clipBehavior: Clip.none, children: [
                Container(
                    // width: 50.0,
                    // height: 50.0,
                    decoration: const BoxDecoration(
                      shape: BoxShape.circle,
                    ),
                    child: ClipOval(
                      child: CachedNetworkImage(
                        key: UniqueKey(),
                        imageUrl: leaderBoardController
                                .leaderBoardData[2].profileImageUrl
                                .toString() +
                            sasToken,
                        width: 50.0,
                        height: 50.0,
                        fit: BoxFit.fill,
                        placeholder: (context, url) => Container(
                          child: Image.asset(
                            "assets/icons/avatar.png",
                            package: "progamification",
                          ),
                        ),
                        errorWidget: (context, url, error) => Container(
                          child: Image.asset(
                            "assets/icons/avatar.png",
                            package: "progamification",
                          ),
                        ),
                      ),
                    )),
                Positioned(
                  bottom: -11,
                  left: 17,
                  child: Container(
                      decoration: BoxDecoration(
                        shape: BoxShape.circle,
                        color: Colors.grey[300],
                        border: Border.all(
                          color: Colors.white,
                          width: 1.5,
                        ),
                      ),
                      child: Padding(
                          padding: EdgeInsets.all(4.0),
                          child: Text(
                            leaderBoardController.leaderBoardData[2].rank
                                .toString(),
                            textAlign: TextAlign.start,
                            style: const TextStyle(
                              fontWeight: FontWeight.w400,
                              fontSize: 14,
                              fontFamily: 'Poppins',
                            ),
                          ))),
                ),
              ]),
              Padding(
                padding: EdgeInsets.only(top: 10.0),
                child: Column(
                  children: [
                    Text(
                      leaderBoardController.leaderBoardData[2].userName
                          .toString(),
                      style: const TextStyle(
                        fontWeight: FontWeight.w600,
                        fontSize: 16,
                        fontFamily: 'PlusJakartaSans-SemiBold',
                      ),
                    ),
                    Text(
                      '${leaderBoardController.leaderBoardData[2].score} points',
                      style: const TextStyle(
                        fontWeight: FontWeight.w400,
                        fontSize: 16,
                        fontFamily: 'PlusJakartaSans-Regular',
                      ),
                    )
                  ],
                ),
              )
            ]),
          ],
        ));
  }
}
