import 'package:flutter/material.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:get/get.dart';

class UserDetails extends StatefulWidget {
  const UserDetails({super.key});

  @override
  State<UserDetails> createState() => _UserDetailsState();
}

class _UserDetailsState extends State<UserDetails> {
  final LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  final GamificationStorageService storageService =
      Get.find<GamificationStorageService>();

  LeaderBoardModel? currentUser = LeaderBoardModel();
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  @override
  void initState() {
    setCurrentUserLeaderBoardData();
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
          left: 15,
          right: 15,
          top: MediaQuery.of(context).size.height * 0.02,
          bottom: MediaQuery.of(context).size.height * 0.02),
      child: Flex(
          direction: Axis.horizontal, // this is unique
          mainAxisAlignment: MainAxisAlignment.start,
          mainAxisSize: MainAxisSize.max,
          crossAxisAlignment: CrossAxisAlignment.start,
          verticalDirection: VerticalDirection.down,
          textDirection: TextDirection.ltr,
          children: [
            CircleAvatar(
              backgroundColor: Colors.white,
              radius: 40.5,
              child: ClipOval(
                child: currentUser!.profileImageUrl.isNotEmpty && sasToken != ''
                    ? Image.network(
                        currentUser!.profileImageUrl.toString() + sasToken,
                        fit: BoxFit.cover,
                        width: 100.0,
                        height: 100.0,
                        loadingBuilder: (context, child, loadingProgress) {
                          if (loadingProgress == null) return child;
                          return const SizedBox(
                              width: 100.0,
                              height: 100.0,
                              child: Icon(
                                Icons.account_circle_rounded,
                                size: 85.0,
                              ));
                        },
                        errorBuilder: (context, child, loadingProgress) =>
                            const SizedBox(
                                width: 100.0,
                                height: 100.0,
                                child: Icon(
                                  Icons.account_circle_rounded,
                                  size: 85.0,
                                )))
                    : const SizedBox(
                        width: 100.0,
                        height: 100.0,
                        child: Icon(
                          Icons.account_circle_rounded,
                          size: 85.0,
                        )),
              ),
            ),
            const SizedBox(
              width: 25,
            ),
            Padding(
              padding: const EdgeInsets.all(5.0),
              child: Wrap(
                direction: Axis.vertical,
                spacing: 23,
                runSpacing: 10,
                children: [
                  Text(
                    currentUser!.userName != '' ? currentUser!.userName : '',
                    style: const TextStyle(
                        fontSize: 20, fontWeight: FontWeight.bold),
                  ),
                  Row(
                      // crossAxisAlignment: CrossAxisAlignment.end,
                      mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                      children: [
                        Container(
                            child: Text.rich(
                          TextSpan(
                            text: 'Rank :',
                            style: const TextStyle(
                                fontSize: 20, fontWeight: FontWeight.bold),
                            children: <TextSpan>[
                              TextSpan(
                                  text: currentUser!.rank.toString(),
                                  style: const TextStyle(
                                      fontWeight: FontWeight.bold)),
                            ],
                          ),
                        )),
                        const SizedBox(
                          width: 25,
                        ),
                        Container(
                            child: Text.rich(
                          TextSpan(
                            text: 'Score :',
                            style: const TextStyle(
                                fontSize: 20, fontWeight: FontWeight.bold),
                            children: <TextSpan>[
                              TextSpan(
                                  text: currentUser!.score.toString(),
                                  style: const TextStyle(
                                      fontWeight: FontWeight.bold)),
                            ],
                          ),
                        )),
                      ])
                ],
              ),
            )
          ]),
    );
  }

  Future<void> setCurrentUserLeaderBoardData() async {
    String userId = await storageService.getString('userId');
    LeaderBoardModel leaderboard =
        leaderBoardController.getLeaderBoardData(userId);
    setState(() {
      currentUser = leaderboard;
    });
  }
}
