// ignore_for_file: library_private_types_in_public_api, no_logic_in_create_state, use_key_in_widget_constructors, prefer_const_constructors_in_immutables

import 'package:progamification/src/components/achievements.dart';
import 'package:progamification/src/components/leaderboard_table.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:flutter/material.dart';
import 'package:progamification/src/services/leaderboard.service.dart';

class LeaderBoard extends StatefulWidget {
  final String userId;
  final String applicationId;
  LeaderBoard(this.userId, this.applicationId);
  @override
  _LeaderBoardState createState() => _LeaderBoardState(userId, applicationId);
}

class _LeaderBoardState extends State<LeaderBoard> {
  late String userId;
  late String applicationId;
  bool isGamificationVisible = true;
  _LeaderBoardState(this.userId, this.applicationId);
  LeaderBoardService leaderBoardService = Get.find();

  final LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();

  @override
  void initState() {
    super.initState();
    getData(userId, applicationId);
  }

  Future<void> getData(String userId, String applicationId) async {
    try {
      await leaderBoardService
          .getLeaderBoard(userId, applicationId)
          .then(leaderBoardController.setData);
    } catch (e) {
      setState(() {
        isGamificationVisible = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return isGamificationVisible
        ? Container(
            padding: const EdgeInsets.only(left: 0, right: 0),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
            ),
            child: Row(
              children: [
                InkWell(
                  onTap: (() async {
                    await leaderBoardController.getData(userId, applicationId);
                    await leaderBoardController.getRewards(
                        userId, applicationId);
                    showLeaderBoard();
                  }),
                  child: Container(
                    margin: const EdgeInsets.all(2),
                    child: const Icon(
                      Icons.sports_score_outlined,
                      color: Colors.black,
                    ),
                  ),
                ),
              ],
            ),
          )
        : Container();
  }

  showLeaderBoard() {
    showModalBottomSheet(
      backgroundColor: Colors.white,
      context: context,
      isScrollControlled: true,
      builder: (BuildContext context) => StatefulBuilder(
        builder: (BuildContext context, setState) => SingleChildScrollView(
          padding: const EdgeInsets.only(
            top: 26,
            right: 0,
            bottom: 6,
          ),
          child: SizedBox(
            height: Get.height * 1,
            width: double.infinity,
            child: Column(
              children: [
                SizedBox(
                    height: MediaQuery.of(context).size.height,
                    child: MaterialApp(
                      home: DefaultTabController(
                        length: 2,
                        child: Scaffold(
                          appBar: AppBar(
                            elevation: 0,
                            backgroundColor: Colors.white,
                            bottom: const TabBar(
                              indicatorSize: TabBarIndicatorSize.label,
                              indicatorWeight: 2.5,
                              labelColor: Colors.black87,
                              unselectedLabelColor: Colors.grey,
                              indicatorColor: Colors.black87,
                              tabs: [
                                Tab(
                                    child: Padding(
                                  padding:
                                      EdgeInsets.only(left: 10.0, right: 10.0),
                                  child: Text(
                                    "Achievements",
                                    style: TextStyle(
                                      fontSize: 18.0,
                                      fontFamily: 'PlusJakartaSans-SemiBold',
                                    ),
                                  ),
                                )),
                                Tab(
                                  child: Padding(
                                      padding: EdgeInsets.only(
                                        left: 10.0,
                                        right: 10.0,
                                      ),
                                      child: Text(
                                        "Leaderboard",
                                        style: TextStyle(
                                          fontSize: 18.0,
                                          fontFamily:
                                              'PlusJakartaSans-SemiBold',
                                        ),
                                      )),
                                ),
                              ],
                            ),
                            titleSpacing: 30,
                            title: Padding(
                                padding: EdgeInsets.only(
                                  bottom:
                                      MediaQuery.of(context).viewInsets.bottom,
                                ),
                                child: FloatingActionButton(
                                  onPressed: (() => Navigator.pop(context)),
                                  elevation: 0,
                                  backgroundColor: Colors.grey[100],
                                  child: const Icon(
                                    Icons.close_sharp,
                                    color: Colors.black,
                                    size: 25,
                                  ),
                                )),
                          ),
                          body: const TabBarView(
                            children: [
                              Achievements(),
                              LeaderBoardTable(),
                            ],
                          ),
                        ),
                      ),
                    )),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
